@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
 class ConsumerLogConstants:
-    PUB_LOG = 'delivery_pub_log'
-    SUB_LOG = 'delivery_sub_log'
+    PUB_LOG = '{}_pub_log'
+    SUB_LOG = '{}_sub_log'
 
     CONSUMER_LOG_ES_BULK_NUM = 1000
     CONSUMER_LOG_ES_BULK_THREAD_NUM = 8
@@ -13,4 +13,4 @@ class ConsumerLogConstants:
 PUB_LOG = 'pub_log'
 SUB_LOG = 'sub_log'
 PUB_LOG_BULK_SAVE = 'pub_log_bulk_save'
-SUB_LOG_BULK_SAVE = 'sub_log_bulk_save'
\ No newline at end of file
+SUB_LOG_BULK_SAVE = 'sub_log_bulk_save'
